"use strict";
// Licensed Materials - Property of IBM
//
// IBM Watson Analytics
//
// (C) Copyright IBM Corp. 2020
//
// US Government Users Restricted Rights - Use, duplication or
// disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
Object.defineProperty(exports, "__esModule", { value: true });
exports.findCustomvisLibPath = void 0;
const constants_1 = require("../constants");
const path = require("path");
const fs = require("fs");
function localNodeModulesRef(_path) {
    return path.join(_path, "node_modules", constants_1.LIB_PACKAGE_NAME);
}
/**
 * Ask NodeJS to resolve the module path for us.
 * @param _createRequire The `module.createRequire` or (now deprecated) `module.createRequireFromPath` method.
 */
function modern(_createRequire) {
    return function nodeResolve(_path) {
        // Create a resolve method for a fictuous index.js module
        const local = _createRequire(path.join(_path, "index.js"));
        let resolved;
        try {
            resolved = local.resolve(constants_1.LIB_PACKAGE_NAME);
        }
        catch (ex) {
            if (ex.code !== "MODULE_NOT_FOUND")
                throw ex;
            // Not found, return null
            return null;
        }
        // The node resolution actually resolves the main module path, derive the package root from that.
        // Warning: this logic only works for absolute module identifiers, not relative ones!
        /** Expect the directory name to match the last part of the absolute module id */
        const expected = path.basename(constants_1.LIB_PACKAGE_NAME);
        // The path should point to a file, so start by taking the directory name
        do {
            resolved = path.dirname(resolved);
        } while (path.basename(resolved) !== expected); // Repeat until the expected name is found
        return resolved;
    };
}
/**
 * "Poor man's" fallback of the node resolution algorithm; simply walk up the directory tree.
 * Used in NodeJS < v10.12.0
 */
function fallback() {
    const reIsRootPath = require("process").platform === "win32" ?
        /^\s*(?:[a-zA-Z]:|[\\\/]{2}[^\\\/]+[\\\/]+[^\\\/]+)?[\\\/]\s*$/ : // Windows
        /^\s*\/\s*/; // Unix
    return function nodeResolve(_path) {
        const root = path.normalize(_path);
        let parent = root;
        let current;
        do {
            current = parent;
            const resolved = localNodeModulesRef(current);
            try {
                const stats = fs.statSync(resolved);
                if (stats.isDirectory())
                    return resolved;
            }
            catch (ex) {
                // Forward any exception that is not ENOENT
                if (ex.code !== "ENOENT")
                    throw ex;
            }
            parent = path.dirname(parent);
        } while (current && !reIsRootPath.test(current) && current !== parent);
        return null;
    };
}
const nodeResolve = (function () {
    /**
     * The NodeJS module module.
     * TypeScript doesn't like importing `"module"` using an import statement(?).
     */
    const module = require("module");
    // Select the appropiate implementation
    if (module.createRequire || module.createRequireFromPath)
        return modern(module.createRequire || module.createRequireFromPath);
    else
        return fallback();
}());
/**
 * Follows NodeJS resolution order to try and find the location of customvis-lib in node_modules.
 * If no path matches, a local path is assumed.
 * @param _path The **directory** path to start searching at (in node_modules).
 * Traverses up the directory tree.
 * @returns The (expected) `package.json` path of customvis lib.
 */
function findCustomvisLibPath(_path) {
    const root = nodeResolve(_path);
    // Fall back to assuming a local node_modules reference
    return path.join(root || localNodeModulesRef(_path), "package.json");
}
exports.findCustomvisLibPath = findCustomvisLibPath;
